summaryrefslogtreecommitdiff
path: root/gcc/conflict.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/conflict.c')
-rw-r--r--gcc/conflict.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/conflict.c b/gcc/conflict.c
index 9851fade3de..48ca1d69e67 100644
--- a/gcc/conflict.c
+++ b/gcc/conflict.c
@@ -183,7 +183,7 @@ conflict_graph_delete (graph)
}
/* Adds a conflict to GRAPH between regs REG1 and REG2, which must be
- distinct. Returns non-zero, unless the conflict is already present
+ distinct. Returns nonzero, unless the conflict is already present
in GRAPH, in which case it does nothing and returns zero. */
int
@@ -232,7 +232,7 @@ conflict_graph_add (graph, reg1, reg2)
return 1;
}
/* Returns non-zero if a conflict exists in GRAPH between regs REG1
and REG2. */
int
@@ -232,7 +232,7 @@ conflict_graph_add (graph, reg1, reg2)
return 1;
}
-/* Returns non-zero if a conflict exists in GRAPH between regs REG1
+/* Returns nonzero if a conflict exists in GRAPH between regs REG1
and REG2. */
int